
{% load i18n %}


{% if not content_only %}
    <div class="modal" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title">
                        {% block title %}
                        {% endblock %}
                    </h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
{% endif %}
                    {% block body %}
                    {% endblock %}
{% if not content_only %}
                </div>
                <div class="modal-footer">
                    {% block footer %}
                    {% endblock %}
                </div>
            </div>
        </div>
    </div>
{% endif %}
